source@mandoc.bsd.lv
 help / color / mirror / Atom feed
* mdocml: implement help(1)
@ 2014-12-05 21:55 schwarze
  0 siblings, 0 replies; only message in thread
From: schwarze @ 2014-12-05 21:55 UTC (permalink / raw)
  To: source

Log Message:
-----------
implement help(1)

Modified Files:
--------------
    mdocml:
        main.c

Revision Data
-------------
Index: main.c
===================================================================
RCS file: /home/cvs/mdocml/mdocml/main.c,v
retrieving revision 1.201
retrieving revision 1.202
diff -Lmain.c -Lmain.c -u -p -r1.201 -r1.202
--- main.c
+++ main.c
@@ -96,6 +96,8 @@ static	void		  version(void) __attribute
 static	int		  woptions(struct curparse *, char *);
 
 static	const int sec_prios[] = {1, 4, 5, 8, 6, 3, 7, 2, 9};
+static	char		  help_arg[] = "help";
+static	char		 *help_argv[] = {help_arg, NULL};
 static	const char	 *progname;
 
 
@@ -142,6 +144,8 @@ main(int argc, char *argv[])
 		search.argmode = ARG_EXPR;
 	else if (strncmp(progname, "whatis", 6) == 0)
 		search.argmode = ARG_WORD;
+	else if (strncmp(progname, "help", 4) == 0)
+		search.argmode = ARG_NAME;
 	else
 		search.argmode = ARG_FILE;
 
@@ -273,15 +277,24 @@ main(int argc, char *argv[])
 	resp = NULL;
 #endif
 
-	/* Quirk for a man(1) section argument without -s. */
-
-	if (search.argmode == ARG_NAME &&
-	    argv[0] != NULL &&
-	    isdigit((unsigned char)argv[0][0]) &&
-	    (argv[0][1] == '\0' || !strcmp(argv[0], "3p"))) {
-		search.sec = argv[0];
-		argv++;
-		argc--;
+	/*
+	 * Quirks for help(1)
+	 * and for a man(1) section argument without -s.
+	 */
+
+	if (search.argmode == ARG_NAME) {
+		if (*progname == 'h') {
+			if (argc == 0) {
+				argv = help_argv;
+				argc = 1;
+			}
+		} else if (argv[0] != NULL &&
+		    isdigit((unsigned char)argv[0][0]) &&
+		    (argv[0][1] == '\0' || !strcmp(argv[0], "3p"))) {
+			search.sec = argv[0];
+			argv++;
+			argc--;
+		}
 	}
 
 	rc = MANDOCLEVEL_OK;
--
 To unsubscribe send an email to source+unsubscribe@mdocml.bsd.lv

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2014-12-05 21:55 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2014-12-05 21:55 mdocml: implement help(1) schwarze

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).